<?php

require_once WICKED_BASE . '/lib/Page/StandardPage.php';

/**
 * Wicked MostPopular class.
 *
 * $Horde: wicked/lib/Page/MostPopular.php,v 1.3 2004/08/11 00:26:34 eraserhd Exp $
 *
 * @author  Tyler Colbert <tyler-hordeml@colberts.us>
 * @version $Revision: 1.3 $
 * @package Wicked
 */
class MostPopular extends Page {

    /**
     * Display modes supported by this page.
     * @var array $supportedModes
     */
    var $supportedModes = array(
        WICKED_MODE_CONTENT => true,
        WICKED_MODE_DISPLAY => true);

    /**
     * Render this page in Content mode.
     *
     * @param integer $numPages  How many (at most) pages should we return?
     *
     * @return string  The page content, or PEAR_Error.
     */
    function content($numPages = 10)
    {
        global $wicked;

        return $wicked->mostPopular($numPages);
    }

    /**
     * Render this page in Display mode.
     *
     * @param integer $numPages  How many (at most) pages should we return?
     *
     * @return mixed  Returns true or PEAR_Error.
     */
    function displayContents($isBlock)
    {
        $numPages = 10;
        $summaries = $this->content($numPages);
        if (is_a($summaries, 'PEAR_Error')) {
            global $notification;
            $notification->push('Error retrieving MostPopular: ' . $summaries->toString(), 'horde.error');
            return $summaries;
        }

        require_once 'Horde/Template.php';
        $template = &new Horde_Template();
        $pages = array();
        foreach ($summaries as $page) {
            $page = &new StandardPage($page);
            $pages[] = array('author' => $page->author(),
                             'created' => $page->formatVersionCreated(),
                             'name' => $page->pageName(),
                             'hits' => $page->hits(),
                             'url' => $page->pageUrl(),
                             'version' => $page->version());
        }
        $template->set('pages', $pages);
        $template->set('hits', true, true);
        $hits = true;

        ob_start();
        require WICKED_TEMPLATES . '/pagelist/header.inc';
        echo $template->fetch(WICKED_TEMPLATES . '/pagelist/pagelist.html');
        require WICKED_TEMPLATES . '/pagelist/footer.inc';
        $contents = ob_get_contents();
        ob_end_clean();
        return $contents;
    }

    function pageName()
    {
        return _("MostPopular");
    }

    function pageUrl($linkpage = 'display.php', $actionid = 'none')
    {
        $url = Horde::applicationUrl($linkpage);
        $url = Util::addParameter($url, 'page', $this->pageName());
        return Util::addParameter($url, 'actionID', $actionid);
    }

}
