--TEST--
Wicked_Driver:: page manipulation methods
--FILE--
<?php

echo "Load... ";

define('WICKED_BASE', dirname(__FILE__) . '/../..');
define('AUTH_HANDLER', false);
require_once WICKED_BASE . '/lib/base.php';

define('TEST_PAGE_1', 'driver-pages.phpt Test Page One');
define('TEST_PAGE_2', 'Renamed driver-pages.phpt Test Page (Called "Two")');

echo "ok\n";

testNewPage();
testUpdateTextAndHistory();
testGetHistoryAndRemoveVersion();
testLock();
testLogPageView();
testRenamePage();
testGetPagesAndGetAllPages();
testPopularity();
testRecentChanges();
testSearches();
testRemoveAllVersions();

function testNewPage()
{
    global $wicked;

    echo "Testing newPage()... ";

    $wicked->removeAllVersions(TEST_PAGE_1);

    if ($wicked->pageExists(TEST_PAGE_1)) {
        printf(_("ERROR(1): Page exists before creation.\n"));
        return;
    }

    $res = $wicked->newPage(TEST_PAGE_1, 'This is a test.');
    if (is_a($res, 'PEAR_Error')) {
        printf(_("ERROR(2): %s\n"), $res->getMessage());
        return;
    }

    if (!$wicked->pageExists(TEST_PAGE_1)) {
        printf(_("ERROR(3): Page does not exist after newPage().\n"));
        return;
    }

    $page = $wicked->retrieveByName(TEST_PAGE_1);
    if (is_a($page, 'PEAR_Error')) {
        printf(_("ERROR(4): %s\n"), $page->getMessage());
        return;
    }

    if ($page['page_text'] != 'This is a test.') {
        printf(_("ERROR(5): Incorrect page text.\n"));
        return;
    }

    echo "ok\n";
}

function testUpdateTextAndHistory()
{
    global $wicked;

    echo "Testing updateText() & retrieveHistory()... ";

    $tcount = 1;
    $res = $wicked->updateText(TEST_PAGE_1, 'Here\'s the new page text.',
                               'Test change.', true);
    if (is_a($res, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $res->getMessage());
        return;
    }

    $tcount++;
    $page = $wicked->retrieveByName(TEST_PAGE_1);
    if (is_a($page, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $page->getMessage());
        return;
    }

    $tcount++;
    if ($page['page_text'] != 'Here\'s the new page text.') {
        printf(_("ERROR(%d): Page text did not match.\n"), $tcount);
        return;
    }

    $last_version = sprintf('%d.%d', $page['page_majorversion'],
                            $page['page_minorversion']);

    $tcount++;
    $res = $wicked->updateText(TEST_PAGE_1, 'Here\'s the second change.',
                               'Test change 2.', false);
    if (is_a($res, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $res->getMessage());
        return;
    }

    $tcount++;
    $page = $wicked->retrieveByName(TEST_PAGE_1);
    if (is_a($page, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $page->getMessage());
        return;
    }

    $tcount++;
    if ($page['page_text'] != 'Here\'s the second change.') {
        printf(_("ERROR(%d): Page text did not match.\n"));
        return;
    }

    $tcount++;
    $res = $wicked->retrieveHistory(TEST_PAGE_1, $last_version);
    if (is_a($res, 'PEAR_Error')) {
        printf(_("ERROR(%d): retrieveHistory(): %s\n"), $tcount,
               $res->getMessage());
        return;
    }

    $tcount++;
    if (count($res) == 0) {
        printf(_("ERROR(%d): no results from retrieveHistory()\n"), $tcount);
        return;
    }

    $page = $res[0];

    $tcount++;
    if ($page['page_text'] != 'Here\'s the new page text.') {
        printf(_("ERROR(%d): retrieveHistory() page doesn't have correct text.\n"), $tcount);
        return;
    }
    
    echo "ok\n";
}

function testGetHistoryAndRemoveVersion()
{
    global $wicked;

    echo "Testing getHistory() & removeVersion()... ";

    $tcount = 1;
    $history = $wicked->getHistory(TEST_PAGE_1);
    if (is_a($history, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $history->getMessage());
        return;
    }

    $tcount++;
    if (count($history) < 2) {
        printf(_("ERROR(%d): there aren't enough history items.\n"), $tcount);
        return;
    }

    $nvers = count($history);
    $item_1 = $history[0];
    $item_1_ver = sprintf('%d.%d', $item_1['page_majorversion'],
                          $item_1['page_minorversion']);

    $tcount++;
    $res = $wicked->removeVersion(TEST_PAGE_1, $item_1_ver);
    if (is_a($res, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $res->getMessage());
        return;
    }

    $tcount++;
    $history = $wicked->getHistory(TEST_PAGE_1);
    if (is_a($history, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $history->getMessage());
        return;
    }

    $tcount++;
    if (count($history) != ($nvers - 1)) {
        printf(_("ERROR(%d): wrong number of versions after removeVersion()\n"),
               $tcount);
        return; 
    }

    $tcount++;
    foreach ($history as $page) {
        $testver = sprintf('%d.%d', $page['page_majorversion'],
                           $page['page_minorversion']);
        if ($testver == $item_1_ver) {
            printf(_("ERROR(%d): after removeVersion(), version still exists.\n"), $tcount);
            return;
        }
    }

    echo "ok\n";
}

function testLock()
{
    global $wicked;

    echo "Testing lock()... ";

    $tcount = 1;
    $page = $wicked->retrieveByName(TEST_PAGE_1);
    if (is_a($page, 'PEAR_Error')) {
        printf(_("ERROR(%d): retrieveByName(): %s\n"), $tcount,
               $page->getMessage());
        return;
    }

    $tcount++;
    if ($page['locked']) {
        printf(_("ERROR(%d): page is already locked.\n"), $tcount);
        return;
    }

    $tcount++;
    $res = $wicked->lock(TEST_PAGE_1, true);
    if (is_a($res, 'PEAR_Error')) {
        printf(_("ERROR(%d): lock(): %s\n"), $tcount, $res->getMessage());
        return;
    }

    $tcount++;
    $page = $wicked->retrieveByName(TEST_PAGE_1);
    if (is_a($page, 'PEAR_Error')) {
        printf(_("ERROR(%d): retrieveByName(): %s\n"), $tcount,
               $page->getMessage());
        return;
    }

    $tcount++;
    if (!$page['locked']) {
        printf(_("ERROR(%d): page was not locked.\n"), $tcount);
        return;
    }

    $tcount++;
    $res = $wicked->lock(TEST_PAGE_1, false);
    if (is_a($res, 'PEAR_Error')) {
        printf(_("ERROR(%d): lock(): %s\n"), $tcount, $res->getMessage());
        return;
    }

    $tcount++;
    $page = $wicked->retrieveByName(TEST_PAGE_1);
    if (is_a($page, 'PEAR_Error')) {
        printf(_("ERROR(%d): retrieveByName(): %s\n"), $tcount,
               $page->getMessage());
        return;
    }

    $tcount++;
    if ($page['locked']) {
        printf(_("ERROR(%d): page was not unlocked.\n"), $tcount);
        return;
    }

    echo "ok\n";
}

function testLogPageView()
{
    global $wicked;

    echo "Testing logPageView()... ";

    $tcount = 1;
    $page = $wicked->retrieveByName(TEST_PAGE_1);
    if (is_a($page, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $page->getMessage());
        return;
    }

    $hits = $page['page_hits'];

    $tcount++;
    $res = $wicked->logPageView(TEST_PAGE_1);
    if (is_a($res, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $res->getMessage());
        return;
    }

    $tcount++;
    $page = $wicked->retrieveByName(TEST_PAGE_1);
    if (is_a($page, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $page->getMessage());
        return;
    }

    if ($page['page_hits'] != $hits + 1) {
        printf(_("ERROR(%d): hits counter not correct.\n"), $tcount);
        return;
    }

    echo "ok\n";
}

function testRenamePage()
{
    global $wicked;

    echo "Testing renamePage()... ";

    $tcount = 1;
    $res = $wicked->renamePage(TEST_PAGE_1, TEST_PAGE_2);
    if (is_a($res, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $res->getMessage());
        return;
    }

    $tcount++;
    if ($wicked->pageExists(TEST_PAGE_1) || !$wicked->pageExists(TEST_PAGE_2)) {
        printf(_("ERROR(%d): rename failed.\n"), $tcount);
        return;
    }

    $tcount++;
    $res = $wicked->renamePage(TEST_PAGE_2, TEST_PAGE_1);
    if (is_a($res, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $res->getMessage());
        return;
    }

    $tcount++;
    if ($wicked->pageExists(TEST_PAGE_2) || !$wicked->pageExists(TEST_PAGE_1)) {
        printf(_("ERROR(%d): rename failed.\n"), $tcount);
        return;
    }

    echo "ok\n";
}

function testGetPagesAndGetAllPages()
{
    global $wicked;

    echo "Testing getPages() & getAllPages()... ";

    $tcount = 1;
    $pages = $wicked->getPages();
    if (is_a($pages, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $pages->getMessage());
        return;
    }

    $tcount++;
    $allPages = $wicked->getAllPages();
    if (is_a($allPages, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $allPages->getMessage());
        return;
    }
    
    $tcount++;
    if (count($allPages) != count($pages)) {
        printf(_("ERROR(%d): different page count.\n"), $tcount);
        return;
    }

    $allPageNames = array();
    foreach ($allPages as $allPage) {
        $allPageNames[] = $allPage['page_name'];
    }

    $tcount++;
    if (count(array_diff($pages, $allPageNames)) > 0 ||
        count(array_diff($allPageNames, $pages)) > 0) {
        printf(_("ERROR(%d): page lists are different.\n"), $tcount);
        return;
    }

    echo "ok\n";
}

function testPopularity()
{
    global $wicked;

    echo "Testing mostPopular() & leastPopular()... ";

    $tcount = 1;
    $res = $wicked->mostPopular();
    if (is_a($res, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $res->getMessage());
        return;
    }

    $tcount++;
    $res = $wicked->leastPopular();
    if (is_a($res, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $res->getMessage());
        return;
    }

    echo "ok\n";
}

function testRecentChanges()
{
    global $wicked;

    echo "Testing getRecentChanges()... ";

    $tcount = 1;
    $res = $wicked->getRecentChanges();
    if (is_a($res, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $res->getMessage());
        return;
    }

    echo "ok\n";
}

function testSearches()
{
    global $wicked;

    echo "Testing searchTitles(), searchText() & getLikePages()... ";

    $tcount = 1;
    $res = $wicked->searchTitles('.phpt');
    if (is_a($res, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $res->getMessage());
        return;
    }

    $tcount++;
    if (count($res) < 1) {
        printf(_("ERROR(%d): didn't find all the pages.\n"), $tcount);
        return;
    }

    $tcount++;
    $res = $wicked->searchText('second change');
    if (is_a($res, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $res->getMessage());
        return;
    }

    $tcount++;
    if (count($res) < 1) {
        printf(_("ERROR(%d): didn't find all the pages.\n"), $tcount);
        return;
    }

    $tcount++;
    $res = $wicked->getLikePages('Wiki');
    if (is_a($res, 'PEAR_Error')) {
        printf(_("ERROR(%d): %s\n"), $tcount, $res->getMessage());
        return;
    }
    
    echo "ok\n";
}

function testRemoveAllVersions()
{
    global $wicked;

    echo "Testing removeAllVersions()... ";

    $res = $wicked->removeAllVersions(TEST_PAGE_1);
    if (is_a($res, 'PEAR_Error')) {
        printf(_("ERROR(1): %s\n"), $res->getMessage());
        return;
    }

    if ($wicked->pageExists(TEST_PAGE_1)) {
        printf(_("ERROR(2): Page still exists.\n"));
        return;
    }

    echo "ok\n";
}

--EXPECT--
Load... ok
Testing newPage()... ok
Testing updateText() & retrieveHistory()... ok
Testing getHistory() & removeVersion()... ok
Testing lock()... ok
Testing logPageView()... ok
Testing renamePage()... ok
Testing getPages() & getAllPages()... ok
Testing mostPopular() & leastPopular()... ok
Testing getRecentChanges()... ok
Testing searchTitles(), searchText() & getLikePages()... ok
Testing removeAllVersions()... ok
